TestSuperKeyboard class

Implemented types

Constructors

TestSuperKeyboard({required String id, required TickerProvider vsync, KeyboardState initialKeyboardState = KeyboardState.closed, double fakeKeyboardHeight = 400.0, Duration keyboardAnimationTime = const Duration(milliseconds: 600)})

Properties

fakeKeyboardHeight → double
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
An ID for this specific test keyboard instance, which is used primarily to ensure that one test keyboard doesn't accidentally uninstall some other test keyboard.
final
mobileGeometry → ValueListenable<MobileWindowGeometry>
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
enablePlatformLogging(bool isEnabled) → Future<void>
Enable/disable platform-side logging, e.g., Android or iOS logs.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

forceUninstall() → void
install({required String id, required TickerProvider vsync, KeyboardState initialKeyboardState = KeyboardState.closed, double fakeKeyboardHeight = _defaultKeyboardHeight, Duration keyboardAnimationTime = const Duration(milliseconds: 600)}) → void
uninstall(String id) → void